@@ -14,7 +14,7 @@ __citation__ = ""
 ########################################################################################################################
 
 from warnings import warn
-
+from . import legacy as _  # monkeypatches singledispatchmethod TypedDict Unpack on older Pythons
 
 try:
     from .igor import Igor
@@ -44,3 +44,4 @@ from .m_rmsd import mRMSD
 from .mpro import MProVictor
 from .mpro import data as mpro_data
 from . import branding
+from .display import display_mols, MolNGLWidget
